/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.core;

import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Parser for constant values. From Wyjec language point of view, constants are simply functions
 * without parameters. The difference lies in their implementation: different constants don't
 * have to be mapped map to different objects (as with {@link pl.chyla.wyjec.core.Function}
 * instances). Instead, single instance of parser can derive constant values directly from their
 * string representations.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public interface IConstantsParser {

    /**
     * Parses given string as a representation of constant value. If parsing of the string is
     * successful, value of recognized constant will be stored in given {@link Value} object and
     * <code>true</code> will be returned; otherwise {@link Value} object will not be modified
     * and the method will return <code>false</code>.
     * <p>
     * Note: support for constants of {@link pl.chyla.wyjec.core.Type#STRING} type is very
     * limited for two reasons:
     * <ul>
     * <li>
     * {@link pl.chyla.wyjec.utils.RawString} instance embedded in {@link Value} instance passed
     * to the method may contain with 0-sized character storage, so it's illegal to append
     * anything to it
     * </li>
     * <li>
     * the resulting value should be fully independent from the input, so it's illegal to use
     * <code>constStr</code> instance directly or its storage as the result
     * </li>
     * </ul>
     *
     * @param result {@link Value} object used to store recognized constant value
     * @param constStr string representation of constant to parse
     * @return
     *     <code>true</code> is parsing was successful (value of parsed constant can be read
     *     using given {@link Value} object), <code>false</code> otherwise
     */
    boolean parseConstant(Value result, ReadableRawString constStr);

}
