/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.core;


/**
 * Interface for object intended for use during function evaluation. It provides access to
 * {@link Value} instances containing actual parameters of currently evaluated function and to
 * {@link Value} instance containing the result that should be set during the evaluation.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public interface IEvaluationContext {

    /**
     * Returns the number of parameters passed to the function.
     *
     * @return the number of function's actual parameters
     */
    int getParametersCount();

    /**
     * Returns {@link Value} instance holding value of actual parameter specified with its
     * index. The returned value should not be modified!
     *
     * @param paramIndex
     *     index of actual parameter to get; it should be nonnegative number less than
     *     {@link #getParametersCount()}, for other values the behaviour of the method is
     *     undefined
     * @return function's actual parameter with given index
     */
    Value getParameter(int paramIndex);

    /**
     * Returns {@link Value} instance holding the result of function evaluation. This instance
     * should be updated during the evaluation (typically, using one of <code>Value.set*</code>
     * methods).
     *
     * @return {@link Value} instance intended for function evaluation result
     */
    Value getResult();

}
