/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.evaluator;

import pl.chyla.wyjec.core.Function;


/**
 * Exception thrown to indicate that an exception occurred during evaluation of one of
 * functions used in an expression. It's not connected with exceptions from Wyjec evaluation
 * engine, but with exceptions from classes implementing different functions, i.e.
 * {@link pl.chyla.wyjec.core.Function} derivatives.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
class FunctionEvaluationException extends RuntimeException {

    /**
     * Constructs <code>EvaluationException</code> instance that describes exception thrown
     * during evaluation of function with given name and parameters.
     *
     * @param func function for which evaluation method threw an exception
     * @param cause exception thrown during evaluation
     */
    FunctionEvaluationException(Function func, Throwable cause) {
        super(
            "Error during evaluation of function"
            + " \"" + func.getName()
            + func.getSignature().getParametersTypesDescription() + "\"",
            cause);
    }

}
