/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.extfuncs.langfuncs;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.IntegerParameter;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.RawString;


/**
 * Uses English grammar rules to choose the appropriate plural form for number specified as the
 * first parameter and returns one of the remaining three string parameters.
 *
 * @wyjec.example "{pluralEN|{3}|dog|dogs}" "dogs" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public abstract class FnBasePluralEN extends StringFunction {

    /**
     * Number determining plural form to use
     * @wyjec.param number
     */
    private static final IntegerParameter pNumber = new IntegerParameter();

    /**
     * Singular form of a word (used when number equals 1)
     * @wyjec.param singular
     */
    private static final StringParameter pSingular = new StringParameter();

    /**
     * First plural form of a word (used when number is not equal to 1)
     * @wyjec.param plural
     */
    private static final StringParameter pPlural = new StringParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pNumber, pSingular, pPlural}, null);

    public final FunctionSignature getSignature() {
        return signature;
    }

    protected final void execute(RawString result) {
        if (getParameter(pNumber) == 1) {
            result.append(getParameter(pSingular));
        } else {
            result.append(getParameter(pPlural));
        }
    }

}
