/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.lexer;

import pl.chyla.wyjec.utils.IntUtils;


/**
 * Class containing all possible token values and helper operations for tokens.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class Token {

    /**
     * Value representing <code>FUNCTION_START</code> token.
     */
    public static final int FUNCTION_START = 0;

    /**
     * Value representing <code>FUNCTION_END</code> token.
     */
    public static final int FUNCTION_END = 1;

    /**
     * Value representing <code>SEPARATOR</code> token.
     */
    public static final int SEPARATOR = 2;

    /**
     * Value representing <code>TERMINATOR</code> token.
     */
    public static final int TERMINATOR = 3;

    /**
     * Value representing <code>STRING</code> token.
     */
    public static final int STRING = 4;

    /**
     * Names of the tokens in order determined by their <code>int</code> representations
     */
    private static final String[] TOKENS_NAMES = {
        "FUNCTION_START",
        "FUNCTION_END",
        "SEPARATOR",
        "TERMINATOR",
        "STRING"
    };

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private Token() { }

    /**
     * Returns symbolic name of a token specified using its <code>int</code> representation.
     *
     * @param tokenType <code>int</code> representation of the token, e.g. <code>STRING</code>
     * @return symbolic name of the token
     * @throws IllegalArgumentException in case invalid <code>tokenType</code> was given
     */
    public static String getName(int tokenType) {
        if (!IntUtils.isBetweenInclusive(tokenType, 0, TOKENS_NAMES.length - 1)) {
            throw new IllegalArgumentException("Invalid token type: " + tokenType);
        }
        return TOKENS_NAMES[tokenType];
    }

}
