/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdconsts;

import pl.chyla.wyjec.core.IConstantsParser;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Parser for standard Wyjec constants, grouping all standard parsers.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class StandardConstantsParser implements IConstantsParser {

    /**
     * Stack of standard constants parsers
     */
    private StackedConstantsParser stdParsersStack = new StackedConstantsParser(
        new IConstantsParser[] {
            IntegerConstantsParser.getInstance(),
            FloatConstantsParser.getInstance(),
            DateConstantsParser.getInstance()});

    /**
     * Private empty constructor to disallow instantiating of the class from outside.
     */
    private StandardConstantsParser() { }

    /**
     * Returns instance of <code>StandardConstantsParser</code> which can be safely used
     * independly from other threads which also get <code>StandardConstantsParser</code> using
     * this method. It's undefined whether this method returns newly created instance or not.
     *
     * @return instance of <code>StandardConstantsParser</code>
     */
    public static StandardConstantsParser getInstance() {
        return new StandardConstantsParser();
    }

    /**
     * Parses given string as one of standard constants of Wyjec language.
     *
     * @param result {@link Value} object used to store recognized constant value
     * @param constStr string representation of constant to parse
     * @return {@inheritDoc}
     */
    public boolean parseConstant(Value result, ReadableRawString constStr) {
        return stdParsersStack.parseConstant(result, constStr);
    }

}
