/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.accessors;

import java.util.Calendar;
import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.DateParameter;
import pl.chyla.wyjec.utils.SimpleCalendar;


/**
 * Returns year number of given date.
 *
 * @wyjec.func year
 * @wyjec.example "{year|{&#64;1977-03-09}}" "1977" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnYear extends IntegerFunction {

    /**
     * Date to retrieve year number from
     * @wyjec.param date
     */
    private static final DateParameter pDate = new DateParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate}, null);

    /**
     * Temporary calendar instance used for calculation
     */
    private SimpleCalendar tmpCal = new SimpleCalendar();

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "year";
    }

    protected long execute() {
        tmpCal.setTimeInMillis(getParameter(pDate));
        return tmpCal.get(Calendar.YEAR);
    }

}
