/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.DateParameter;


/**
 * Returns difference between two dates represented by number of minutes (it's rounded towards 0
 * to integral number of minutes). First date is subtracted from second one.
 *
 * @wyjec.func -minutes
 * @wyjec.example "{-minutes|{&#64;1978-09-11}|{&#64;1977-03-09}}" "793440" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnSubtractionMinutes extends IntegerFunction {

    /**
     * First date to calculate difference for (minuend)
     * @wyjec.param date1
     */
    private static final DateParameter pDate1 = new DateParameter();

    /**
     * Second date to calculate difference for (subtrahend)
     * @wyjec.param date2
     */
    private static final DateParameter pDate2 = new DateParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate1, pDate2}, null);

    /**
     * The number of milliseconds in the minute
     */
    private static final long MILLISECONDS_PER_MINUTE = 1000L * 60L;

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "-minutes";
    }

    protected long execute() {
        return (getParameter(pDate1) - getParameter(pDate2)) / MILLISECONDS_PER_MINUTE;
    }

}
