/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.basic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.DateParameter;
import pl.chyla.wyjec.utils.RawString;
import pl.chyla.wyjec.utils.SimpleCalendar;


/**
 * Returns string representation of date given as a parameter. It consists of date and time
 * of the day separated by space, both given in format specified by ISO 8601 standard.
 *
 * @wyjec.func str
 * @wyjec.example "{str|{&#64;1977-03-09 21:00:00}}" "1977-03-09 21:00:00" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnStr extends StringFunction {

    /**
     * Date to represent as a string
     * @wyjec.param date
     */
    private static final DateParameter pDate = new DateParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate}, null);

    /**
     * Temporary calendar instance used for accessing date fields
     */
    private SimpleCalendar tmpCal = new SimpleCalendar();

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "str";
    }

    protected void execute(RawString result) {
        tmpCal.setTimeInMillis(getParameter(pDate));
        DateFormatUtils.appendISODate(result, tmpCal);
        result.append(' ');
        DateFormatUtils.appendISOTime(result, tmpCal);
    }

}
