/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.relations;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.BooleanFunction;
import pl.chyla.wyjec.core.optparameters.DateOptParameters;
import pl.chyla.wyjec.core.parameters.DateParameter;


/**
 * Returns boolean true if all dates given as parameters have the same value and boolean
 * false otherwise.
 *
 * @wyjec.func =
 * @wyjec.example "{=|{&#64;1977-03-09 00:00:00}|{&#64;1977-03-09}}" "true" boolean
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnEqual extends BooleanFunction {

    /**
     * First date used in comparision
     * @wyjec.param date
     */
    private static final DateParameter pDate = new DateParameter();

    /**
     * Other optional dates to compare to the first one
     * @wyjec.param optDates
     */
    private static final DateOptParameters pOptDates = new DateOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate}, pOptDates);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "=";
    }

    protected boolean execute() {
        long firstValue = getParameter(pDate);
        int optParamsCount = getOptParametersCount(pOptDates);
        for (int i = 0; i < optParamsCount; i++) {
            if (getParameter(pOptDates, i) != firstValue) {
                return false;
            }
        }
        return true;
    }

}
