/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.relations;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.BooleanFunction;
import pl.chyla.wyjec.core.optparameters.DateOptParameters;
import pl.chyla.wyjec.core.parameters.DateParameter;


/**
 * Returns boolean true if every function's parameter after the first one is less than its
 * predecessor and boolean false otherwise. If only one parameter is given, function always
 * returns true. "less" means here that date represented by a value is before the other one.
 *
 * @wyjec.func <
 * @wyjec.example "{<|{&#64;1977-03-09}|{&#64;1977-03-09}}" "false" boolean
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnLess extends BooleanFunction {

    /**
     * First date used in comparision
     * @wyjec.param date
     */
    private static final DateParameter pDate = new DateParameter();

    /**
     * Other optional dates used in comparision
     * @wyjec.param optDates
     */
    private static final DateOptParameters pOptDates = new DateOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDate}, pOptDates);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "<";
    }

    protected boolean execute() {
        long prevDate = getParameter(pDate);
        int optParamsCount = getOptParametersCount(pOptDates);
        for (int i = 0; i < optParamsCount; i++) {
            long date = getParameter(pOptDates, i);
            if (!(prevDate < date)) {
                return false;
            }
            prevDate = date;
        }
        return true;
    }

}
