/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.basic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.FloatParameter;
import pl.chyla.wyjec.utils.DoubleFormatter;
import pl.chyla.wyjec.utils.RawString;


/**
 * Returns string representation of number given as a parameter. For <code>NaN</code> it returns
 * <code>"NaN"</code>.
 *
 * @wyjec.func str
 * @wyjec.example "{str|{11.5}}" "11.5" string
 * @wyjec.example "{str|{/|{0.0}|{0.0}}}" "NaN" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnStr extends StringFunction {

    /**
     * Number to represent as a string
     * @wyjec.param value
     */
    private static final FloatParameter pValue = new FloatParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    /**
     * Temporary buffer used for generating the result
     */
    private final char[] tmpBuf = new char[DoubleFormatter.MAX_CHARACTERS_COUNT];

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "str";
    }

    protected void execute(RawString result) {
        int charsCount = DoubleFormatter.formatToArray(getParameter(pValue), tmpBuf, 0);
        result.append(tmpBuf, 0, charsCount);
    }

}
