/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.selection;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.FloatFunction;
import pl.chyla.wyjec.core.optparameters.FloatOptParameters;
import pl.chyla.wyjec.core.parameters.FloatParameter;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Returns one of given numbers depending on value of selector. Selector specifies 0-based
 * index of number from given sequence of optional number. In case index is negative or too
 * big, default number is returned.
 *
 * @wyjec.func select
 * @wyjec.example "{select|{0.0}|{3}|{10.0}|{10.5}|{11.0}|{11.5}|{12.0}}" "11.5" float
 * @wyjec.example "{select|{0.0}|{1}|{10.0}|{10.5}|{/|{0.0}|{0.0}}}" "10.5" float
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnSelect extends FloatFunction {

    /**
     * Default number used as result of the function in case selector is negative or greater
     * than length of sequence of numbers
     * @wyjec.param defaultValue
     */
    private static final FloatParameter pDefaultValue = new FloatParameter();

    /**
     * Index of value from sequence of numbers to return as result
     * @wyjec.param selector
     */
    private static final IntegerParameter pSelector = new IntegerParameter();

    /**
     * Optional sequence of numbers to select single value from (may be empty)
     * @wyjec.param optValues
     */
    private static final FloatOptParameters pOptValues = new FloatOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDefaultValue, pSelector}, pOptValues, true);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "select";
    }

    protected double execute() {
        int selectorValue = (int) getParameter(pSelector);
        if (selectorValue >= 0 && selectorValue < getOptParametersCount(pOptValues)) {
            return getParameter(pOptValues, selectorValue);
        } else {
            return getParameter(pDefaultValue);
        }
    }

}
