/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.basic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.FloatParameter;


/**
 * Converts given float number to its equivalent of integer type, dropping non-integral
 * part (rounding towards 0). For float values greater than maximum integer value (including
 * positive infinity) this function returns maximum integer: <code>9223372036854775807</code>.
 * For negative float values less than minimum integer value (including negative infinity)
 * this function returns minimum integer: <code>-9223372036854775808</code>. For
 * <code>NaN</code> value and for float values with absolute value less than 0 this function
 * returns 0.
 *
 * @wyjec.func int
 * @wyjec.example "{int|{-11.0}}" "-11" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnIntFromFloat extends IntegerFunction {

    /**
     * Number to convert to integer type
     * @wyjec.param value
     */
    private static final FloatParameter pValue = new FloatParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "int";
    }

    protected long execute() {
        return (long) getParameter(pValue);
    }

}
