/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnAddition;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnFind;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnLPad;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnLStrip;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnLen;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnLower;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnRPad;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnRStrip;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnRepeat;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnReplace;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnReverse;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnSubStr;
import pl.chyla.wyjec.stdfuncs.stringfuncs.ops.FnUpper;
import pl.chyla.wyjec.stdfuncs.stringfuncs.relations.FnEqual;
import pl.chyla.wyjec.stdfuncs.stringfuncs.relations.FnGreater;
import pl.chyla.wyjec.stdfuncs.stringfuncs.relations.FnGreaterOrEqual;
import pl.chyla.wyjec.stdfuncs.stringfuncs.relations.FnLess;
import pl.chyla.wyjec.stdfuncs.stringfuncs.relations.FnLessOrEqual;
import pl.chyla.wyjec.stdfuncs.stringfuncs.selection.FnIf;
import pl.chyla.wyjec.stdfuncs.stringfuncs.selection.FnMax;
import pl.chyla.wyjec.stdfuncs.stringfuncs.selection.FnMin;
import pl.chyla.wyjec.stdfuncs.stringfuncs.selection.FnSelect;
import pl.chyla.wyjec.stdfuncs.stringfuncs.specialchars.FnLCurly;
import pl.chyla.wyjec.stdfuncs.stringfuncs.specialchars.FnRCurly;
import pl.chyla.wyjec.stdfuncs.stringfuncs.specialchars.FnVBar;


/**
 * Factory for all standard functions operating on values of Wyjec's string type.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class StringFunctions {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private StringFunctions() { }

    /**
     * Returns array of {@link pl.chyla.wyjec.core.Function} instances representing all standard
     * string functions.
     *
     * @return new list of instances of standard string functions
     */
    public static Function[] getFunctions() {
        return new Function[] {
            new FnAddition(),
            new FnRepeat(),
            new FnEqual(), new FnGreaterOrEqual(), new FnGreater(), new FnLessOrEqual(),
            new FnLess(),
            new FnMin(), new FnMax(),
            new FnIf(), new FnSelect(),
            new FnUpper(), new FnLower(), new FnReplace(), new FnFind(), new FnReverse(),
            new FnLen(),
            new FnSubStr(), new FnLPad(), new FnRPad(), new FnLStrip(), new FnRStrip(),
            new FnLCurly(), new FnRCurly(), new FnVBar()};
    }

}
