/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.IntegerParameter;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.RawString;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Generates new string by concatenating together specified number of copies of given
 * string. For negative number of repetitions the function returns an empty string.
 *
 * @wyjec.func repeat
 * @wyjec.example "{repeat|**|{3}}" "******" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnRepeat extends StringFunction {

    /**
     * Base string used to generate the new one
     * @wyjec.param value
     */
    private static final StringParameter pValue = new StringParameter();

    /**
     * Number of repetitions of the base string
     * @wyjec.param repetitions
     */
    private static final IntegerParameter pRepetitions = new IntegerParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue, pRepetitions}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "repeat";
    }

    protected void execute(RawString result) {
        long reps = getParameter(pRepetitions);
        ReadableRawString str = getParameter(pValue);
        for (int i = 0; i < reps; i++) {
            result.append(str);
        }
    }

}
